Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1495)

Unified Diff: dart/sdk/lib/core/string_buffer.dart

Issue 12296011: Version 0.3.7.4 (Closed) Base URL: http://dart.googlecode.com/svn/trunk/
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « dart/sdk/lib/core/list.dart ('k') | dart/sdk/lib/core/string_sink.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dart/sdk/lib/core/string_buffer.dart
===================================================================
--- dart/sdk/lib/core/string_buffer.dart (revision 18634)
+++ dart/sdk/lib/core/string_buffer.dart (working copy)
@@ -9,29 +9,69 @@
* efficiently. Only on a call to [toString] are the strings
* concatenated to a single String.
*/
-abstract class StringBuffer {
+class StringBuffer implements StringSink {
/// Creates the string buffer with an initial content.
- external factory StringBuffer([Object content = ""]);
+ external StringBuffer([Object content = ""]);
/// Returns the length of the buffer.
- int get length;
+ external int get length;
- // Returns whether the buffer is empty.
- bool get isEmpty;
+ /// Returns whether the buffer is empty.
+ bool get isEmpty => length == 0;
- /// Converts [obj] to a string and adds it to the buffer.
- void add(Object obj);
+ /**
+ * Converts [obj] to a string and adds it to the buffer.
+ *
+ * *Deprecated*. Use [write] instead.
+ */
+ @deprecated
+ void add(Object obj) => write(obj);
+ external void write(Object obj);
+
+ void writeAll(Iterable objects) {
+ for (Object obj in objects) write(obj);
+ }
+
+ void writeln(Object obj) {
+ write(obj);
+ write("\n");
+ }
+
+ /**
+ * Adds the string representation of [charCode] to the buffer.
+ *
+ * *Deprecated* Use [writeCharCode] instead.
+ */
+ @deprecated
+ void addCharCode(int charCode) {
+ writeCharCode(charCode);
+ }
+
/// Adds the string representation of [charCode] to the buffer.
- void addCharCode(int charCode);
+ void writeCharCode(int charCode) {
+ write(new String.fromCharCode(charCode));
+ }
- /// Adds all items in [objects] to the buffer.
- void addAll(Iterable objects);
+ /**
+ * Adds all items in [objects] to the buffer.
+ *
+ * *Deprecated*. Use [writeAll] instead.
+ */
+ @deprecated
+ void addAll(Iterable objects) {
+ for (Object obj in objects) write(obj);
+ }
- /// Clears the string buffer.
- void clear();
+ /**
+ * Clears the string buffer.
+ *
+ * *Deprecated*.
+ */
+ @deprecated
+ external void clear();
/// Returns the contents of buffer as a concatenated string.
- String toString();
+ external String toString();
}
« no previous file with comments | « dart/sdk/lib/core/list.dart ('k') | dart/sdk/lib/core/string_sink.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698